#' `ebirdst`: Tools to Load, Map, Plot, and Analyze eBird Status and Trends
#' Data Products
#'
#' Tools to load, map, plot, and analyze [eBird Status and
#' Trends](https://ebird.org/science/status-and-trends) data products
#'
#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @importFrom rlang .data
## usethis namespace: end
NULL
